monkey.mailman.core-async

Provides functionality for async event handling using core.async, including an in-memory implementation of a broker. This is similar to the one provided in the core lib and is mainly useful for testing/development purposes.

Provides functionality for async event handling using [core.async](https://clojure.github.io/core.async/),
including an in-memory implementation of a broker.  This is similar to
the one provided in the core lib and is mainly useful for testing/development
purposes.
raw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries