monkey.mailman.core-async

Provides functionality for async event handling using core.async, including an in-memory implementation of a broker. This is similar to the one provided in the core lib and is mainly useful for testing/development purposes.

Provides functionality for async event handling using [core.async](https://clojure.github.io/core.async/),
including an in-memory implementation of a broker.  This is similar to
the one provided in the core lib and is mainly useful for testing/development
purposes.
raw docstring

async-invokerclj

(async-invoker handlers evt)

Routing invoker that dispatches each handler in its own go-block, collecting all results into a single channel. Returns a channel that will yield a vector of all handler results.

Routing invoker that dispatches each handler in its own go-block, collecting
all results into a single channel.  Returns a channel that will yield a vector
of all handler results.
sourceraw docstring

core-async-brokerclj

(core-async-broker & {:keys [channel buf-size] :or {buf-size 10}})

Creates a new core.async broker with an optional buffer size (default: 10).

Creates a new core.async broker with an optional buffer size (default: 10).
sourceraw docstring

get-channelclj

(get-channel m)

Retrieves the channel configured on the broker

Retrieves the channel configured on the broker
sourceraw docstring

start-brokerclj

(start-broker broker)

Starts a go-loop that reads events from the broker channel and dispatches them to all registered listeners.

Starts a go-loop that reads events from the broker channel and dispatches
them to all registered listeners.
sourceraw docstring

stop-brokerclj

(stop-broker broker)

Closes the broker channel, which terminates the go-loop.

Closes the broker channel, which terminates the go-loop.
sourceraw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries